@@ -10,8 +10,8 @@ class SkipGramKarateClub(AbstractKarateClubEmbedder):
     def __init__(
         self,
         embedding_size: int = 100,
-        walk_number: int = 10,
-        walk_length: int = 80,
+        iterations: int = 10,
+        walk_length: int = 128,
         window_size: int = 5,
         p: float = 1.0,
         q: float = 1.0,
@@ -36,9 +36,9 @@ class SkipGramKarateClub(AbstractKarateClubEmbedder):
         ----------------------
         embedding_size: int = 100
             Size of the embedding to use.
-        walk_number: int = 10
+        iterations: int = 10
             Number of random walks. Default is 10.
-        walk_length: int = 80
+        walk_length: int = 128
             Length of random walks. Default is 80.
         window_size: int = 5
             Matrix power order. Default is 5.
@@ -61,7 +61,7 @@ class SkipGramKarateClub(AbstractKarateClubEmbedder):
             Whether to enable the cache, that is to
             store the computed embedding.
         """
-        self._walk_number=walk_number
+        self._iterations=iterations
         self._walk_length=walk_length
         self._workers=cpu_count()
         self._window_size=window_size
@@ -81,7 +81,7 @@ class SkipGramKarateClub(AbstractKarateClubEmbedder):
         """Returns the parameters used in the model."""
         return dict(
             **super().parameters(),
-            walk_number=self._walk_number,
+            iterations=self._iterations,
             walk_length=self._walk_length,
             window_size=self._window_size,
             p=self._p,
@@ -96,7 +96,7 @@ class SkipGramKarateClub(AbstractKarateClubEmbedder):
         """Returns parameters for smoke test."""
         return dict(
             **AbstractKarateClubEmbedder.smoke_test_parameters(),
-            walk_number=1,
+            iterations=1,
             walk_length=8,
             window_size=2,
             epochs=1,
@@ -105,7 +105,7 @@ class SkipGramKarateClub(AbstractKarateClubEmbedder):
     def _build_model(self) -> Node2Vec:
         """Return new instance of the Node2Vec CBOW model."""
         return Node2Vec(
-            walk_number=self._walk_number,
+            walk_number=self._iterations,
             walk_length=self._walk_length,
             dimensions=self._embedding_size,
             workers=self._workers,
