@@ -10,8 +10,8 @@ class WalkletsSkipGramKarateClub(AbstractKarateClubEmbedder):
     def __init__(
         self,
         embedding_size: int = 100,
-        walk_number: int = 10,
-        walk_length: int = 80,
+        iterations: int = 10,
+        walk_length: int = 128,
         window_size: int = 5,
         epochs: int = 10,
         learning_rate: float = 0.05,
@@ -26,9 +26,9 @@ class WalkletsSkipGramKarateClub(AbstractKarateClubEmbedder):
         ----------------------
         embedding_size: int = 100
             Size of the embedding to use.
-        walk_number: int = 10
+        iterations: int = 10
             Number of random walks. Default is 10.
-        walk_length: int = 80
+        walk_length: int = 128
             Length of random walks. Default is 80.
         window_size: int = 5
             Matrix power order. Default is 5.
@@ -47,7 +47,7 @@ class WalkletsSkipGramKarateClub(AbstractKarateClubEmbedder):
             Whether to enable the cache, that is to
             store the computed embedding.
         """
-        self._walk_number = walk_number
+        self._iterations = iterations
         self._walk_length = walk_length
         self._workers = cpu_count()
         self._window_size = window_size
@@ -67,7 +67,7 @@ class WalkletsSkipGramKarateClub(AbstractKarateClubEmbedder):
         parameters["embedding_size"] = parameters["embedding_size"] * self._window_size
         return dict(
             **parameters,
-            walk_number=self._walk_number,
+            iterations=self._iterations,
             walk_length=self._walk_length,
             window_size=self._window_size,
             epochs=self._epochs,
@@ -80,7 +80,7 @@ class WalkletsSkipGramKarateClub(AbstractKarateClubEmbedder):
         """Returns parameters for smoke test."""
         return dict(
             **AbstractKarateClubEmbedder.smoke_test_parameters(),
-            walk_number=1,
+            iterations=1,
             walk_length=8,
             window_size=1,
             epochs=1,
@@ -89,7 +89,7 @@ class WalkletsSkipGramKarateClub(AbstractKarateClubEmbedder):
     def _build_model(self) -> Walklets:
         """Return new instance of the Walklets model."""
         return Walklets(
-            walk_number=self._walk_number,
+            walk_number=self._iterations,
             walk_length=self._walk_length,
             dimensions=self._embedding_size,
             workers=self._workers,
