@@ -3,7 +3,7 @@ from typing import List, Union, Optional
 
 import numpy as np
 import pandas as pd
-from userinput.utils import closest
+from userinput.utils import must_be_in_set
 from ensmallen import express_measures
 from embiggen.utils.abstract_models import format_list
 from embiggen.embedding_transformers.node_transformer import NodeTransformer
@@ -346,35 +346,16 @@ class EdgeTransformer:
             If these two mappings do not match, the generated edge embedding
             will be meaningless.
         """
-        if isinstance(method, str) and method.lower() not in [
-            None if method_name is None else method_name.lower()
-            for method_name in EdgeTransformer.methods
-        ]:
-            raise ValueError((
-                "Given method '{}' is not supported. "
-                "Supported methods are {}, or alternatively a lambda. "
-                "Maybe you meant {}?"
-            ).format(
-                method,
-                format_list(
-                    [method for method in EdgeTransformer.methods.keys() if method is not None]),
-                closest(method, [
-                    method_name
-                    for method_name in EdgeTransformer.methods
-                    if method_name is not None
-                ])
-            ))
+        method = must_be_in_set(
+            method,
+            self.methods,
+            "edge embedding method"
+        )
         self._transformer = NodeTransformer(
             aligned_mapping=aligned_mapping,
         )
         self._method_name = method
-        if self._method_name is None:
-            self._method = EdgeTransformer.methods[None]
-        else:
-            self._method = {
-                None if method_name is None else method_name.lower(): callback
-                for method_name, callback in EdgeTransformer.methods.items()
-            }[self._method_name.lower()]
+        self._method = self.methods[method]
 
     @property
     def method(self) -> str:
@@ -394,18 +375,7 @@ class EdgeTransformer:
             Node feature to use to fit the transformer.
         node_type_feature: Optional[Union[pd.DataFrame, np.ndarray, List[Union[pd.DataFrame, np.ndarray]]]] = None
             Node type feature to use to fit the transformer.
-
-        Raises
-        -------------------------
-        ValueError
-            If the given method is None there is no need to call the fit method.
         """
-        if self._method is None:
-            raise ValueError(
-                "There is no need to call the fit when edge method is None, "
-                "as the transformer will exclusively return the numeric node "
-                "indices and not any node feature."
-            )
         self._transformer.fit(
             node_feature,
             node_type_feature=node_type_feature
@@ -472,10 +442,6 @@ class EdgeTransformer:
                     "numpy arrays of type uint32, but you have provided objects of type "
                     f"{sources.dtype} and {destinations.dtype}. "
                 )
-            if self._transformer._node_feature.dtype != np.float32:
-                self._transformer._node_feature = self._transformer._node_feature.astype(
-                    np.float32
-                )
             if not self._transformer._node_feature.data.c_contiguous:
                 self._transformer._node_feature = np.ascontiguousarray(
                     self._transformer._node_feature
